<?

# [Muestra los tags HTML sin ejecutarlos.] 
function sec_cleanHTML ($var) {
    return htmlentities($var);
    //return htmlspecialchars($str);
}

# [Quita todos los tags HTML y PHP de la variable.] 
function sec_cleanTAGS ($var) {
    return strip_tags($var);
}


# [Agrega escape de caracteres especiales SQL -> \' ]        
function sec_addESC($var) {

    if (!get_magic_quotes_gpc()){
	$var = addslashes($var);
    }
                    
    return $var;

}

?>