CREATE TABLE IF NOT EXISTS `alert_config` (
  `id` int(11) NOT NULL auto_increment,
  `name` varchar(255) default NULL,
  `log_type` varchar(255) default NULL,
  `severity` varchar(255) default NULL,
  `log_action` varchar(255) default NULL,
  `log_group` varchar(255) default NULL,
  `log_contains` varchar(255) default NULL,
  `log_exclude` varchar(255) default NULL,
  `occurrences_number` int(11) default NULL,
  `occurrences_within` int(11) default NULL,
  `criticality` varchar(255) default NULL,
  `active_email` int(255) default NULL,
  `email` varchar(255) default NULL,
  PRIMARY KEY  (`id`)
) ;
