<div class="boxmenu" >
		<a href="content_simple_realtime.php" >Simple View</a> | 
		<a href="contenedor.php" >Advance View</a> |
		<a href="alert_list.php" >Alerts</a> |
		<a href="report_show.php?id=2" >Report</a> | 
		<a href="statistic_graph.php" >Statistic</a> | 
		<a href="settings.php" >Settings</a> | 
		<a href="logout.php" >Logout</a> 
</div>